pub struct Gift<M> { /* private fields */ }Expand description
An opaque handle that is granted to the client. The server
owns the resource, and the client obtains a handle to it for
subsequent use with Gift::cite.
Implementations