TrailerRecv

Struct TrailerRecv 

pub struct TrailerRecv { /* private fields */ }
Trailer receive handle.

Implementations

Source

impl TrailerRecv

pub fn release(&mut self, n: usize)

Returns n bytes of credit to the peer.

Only meaningful on a trailer obtained in manual-credit mode — via CallContext::trailer_manual_credit or CallResult::into_response_trailer_manual_credit.

Deadlocks

Never attempt to receive multiple chunks or a fixed amount of data (e.g. via AsyncReadExt::read_exact) between credit releases, or a deadlock may result.

Panics

In debug builds, if called on an automatic trailer, or if the running total exceeds the bytes actually delivered.